@@ -17,7 +17,7 @@
  * Boston, MA 02110-1301, USA.
  */
 
-#if !defined(__WEBKIT_H_INSIDE__) && !defined(WEBKIT2_COMPILATION)
+#if !defined(__WEBKIT_H_INSIDE__) && !defined(__WEBKIT_WEB_PROCESS_EXTENSION_H_INSIDE__) && !defined(BUILDING_WEBKIT)
 #error "Only <wpe/webkit.h> can be included directly."
 #endif
 
@@ -29,8 +29,8 @@
 G_BEGIN_DECLS
 
 #define WEBKIT_MAJOR_VERSION (2)
-#define WEBKIT_MINOR_VERSION (38)
-#define WEBKIT_MICRO_VERSION (5)
+#define WEBKIT_MINOR_VERSION (40)
+#define WEBKIT_MICRO_VERSION (0)
 
 #define WEBKIT_CHECK_VERSION(major, minor, micro) \
     (WEBKIT_MAJOR_VERSION > (major) || \
